/* 
 * my_rand.c $Date: 91/07/01 18:45:25 $
 * $What: <@(#) my_rand.c,v	2.1> $ 
 */

/*
 * This random number generator is from Park and Miller, 
 * "Random Number Generators: Good Ones Are Hard to Find,"
 * _Communications of the ACM_, vol. 31, no. 10 (Oct. 1988),
 * pp. 1192-1201. 
 *
 * NOTE that this implementation is only suitable on systems
 * where a long integer is 32 bits wide.
 */

/* 
 * I use the current time (the number of seconds since the UNIX 
 * epoch, as returned by time()) as a random number seed.  Obviously, 
 * if your system doesn't support time(), you will have do to
 * something else.  Note also that there's nothing special about
 * either time or the UNIX epoch; any routine which returns a 
 * long int and doesn't always return the same thing will be O.K.
 */

#include <sys/types.h>
#include <time.h>

#ifndef NULL
#define NULL 0
#endif

#include "shop.h"

#define A 16807
#define M 2147483647
#define Q 127773
#define R 2836

/*
 * Q is M / A, while R is M mod A.
 */

static BOOLEAN seed_set = FALSE;
static long int my_seed;

long int my_rand()
{
	long int lo, hi, test;
	time_t time();

	if (!seed_set) {
		my_seed = (long int) time(NULL);
		seed_set = TRUE;
	}

	hi = (long) (my_seed / Q);
	lo = my_seed - Q * hi;
	test = A * lo - R * hi;
	if (test > 0) {
		my_seed = test;
	} else {
		my_seed = test + M;
	}
	return my_seed;
}

